@@ -8,6 +8,7 @@ import os
 
 from efl import evas
 from efl.evas import EVAS_HINT_EXPAND, EVAS_HINT_FILL, \
+    EXPAND_BOTH, FILL_BOTH, EXPAND_HORIZ, FILL_HORIZ, \
     EVAS_ASPECT_CONTROL_VERTICAL, Rectangle
 from efl.ecore import Timer
 from efl import elementary
@@ -28,10 +29,6 @@ from efl.elementary.radio import Radio
 from efl.elementary.check import Check
 from efl.elementary.entry import Entry
 
-EXPAND_BOTH = EVAS_HINT_EXPAND, EVAS_HINT_EXPAND
-EXPAND_HORIZ = EVAS_HINT_EXPAND, 0.0
-FILL_BOTH = EVAS_HINT_FILL, EVAS_HINT_FILL
-FILL_HORIZ = EVAS_HINT_FILL, 0.5
 
 script_path = os.path.dirname(os.path.abspath(__file__))
 img_path = os.path.join(script_path, "images")
@@ -150,12 +147,22 @@ def genlist_clicked(obj, item=None):
     vbx.pack_end(bt_1500)
     bt_1500.show()
 
+    def tooltip_content_cb(gl, item, obj):
+        txt = "Tooltip <b>from callback</b> for item # %d" % item.data
+        return Label(gl, text=txt)
+
     for i in range(0, 2000):
         gli = gl.item_append(itc1, i, func=gl_item_sel)
+
+        if i % 2:
+            gli.tooltip_text_set("Static Tooltip for item # %d" % i)
+        else:
+            gli.tooltip_content_cb_set(tooltip_content_cb)
+
         if i == 50:
-            bt_50._callback_add("clicked", lambda bt, it: it.bring_in(), gli)
+            bt_50.callback_clicked_add(lambda bt, it: it.bring_in(), gli)
         elif i == 1500:
-            bt_1500._callback_add("clicked", lambda bt, it: it.bring_in(), gli)
+            bt_1500.callback_clicked_add(lambda bt, it: it.bring_in(), gli)
 
     win.resize(480, 800)
     win.show()
@@ -678,7 +685,6 @@ def genlist20_search_cb(en, gl, tg):
         en.focus = True
     elif gl.selected_item:
         gl.selected_item.selected = False
-        
 
 def genlist20_clicked(obj, item=None):
     win = StandardWindow("genlist-search-by-text",
@@ -731,8 +737,66 @@ def genlist20_clicked(obj, item=None):
 
     win.show()
 
+
+### Genlist reorder mode
+class ItemClass11(GenlistItemClass):
+    def text_get(self, obj, part, data):
+        if part == "elm.text":
+            return "Item # %d" % data
+
+    def content_get(self, obj, part, data):
+        if part == "elm.swallow.icon":
+            return Icon(obj, file=os.path.join(img_path, "logo_small.png"))
+
+def genlist11_focus_highlight_ck_changed_cb(chk, win):
+    win.focus_highlight_enabled = chk.state
+
+def genlist11_reorder_tg_changed_cb(chk, gl):
+    gl.reorder_mode = chk.state
+
+def genlist11_clicked(obj, item=None):
+    win = StandardWindow("genlist-reorder-mode", "Genlist Reorder Mode",
+                         autodel=True, size=(350, 500))
+
+    gl = Genlist(win, size_hint_align=FILL_BOTH, size_hint_weight=EXPAND_BOTH)
+
+    bx = Box(win, size_hint_weight=EXPAND_BOTH)
+    win.resize_object_add(bx)
+    bx.show()
+
+    lb = Label(win)
+    lb.text = "<align=left>Enable reorder mode if you want to move items.<br>" \
+              "To move longress with mouse.</align>"
+    fr = Frame(win, text="Reorder Mode", content=lb,
+               size_hint_weight=EXPAND_HORIZ, size_hint_align=FILL_HORIZ)
+    bx.pack_end(fr)
+    fr.show()
+
+    hbx = Box(win, horizontal=True, padding=(20,0),
+              size_hint_weight=EXPAND_HORIZ)
+    bx.pack_end(hbx)
+    hbx.show()
+
+    tg = Check(win, style="toggle", text="Reorder Mode:")
+    tg.callback_changed_add(genlist11_reorder_tg_changed_cb, gl)
+    hbx.pack_end(tg)
+    tg.show()
+
+    ck = Check(win, text="Focus Highlight")
+    ck.state = win.focus_highlight_enabled
+    ck.callback_changed_add(genlist11_focus_highlight_ck_changed_cb, win)
+    hbx.pack_end(ck)
+    ck.show()
+
+    itc11 = ItemClass11()
+    for i in range(1,50):
+        gl.item_append(itc11, i)
+    bx.pack_end(gl)
+    gl.show()
+
+    win.show()
+
 if __name__ == "__main__":
-    elementary.init()
     win = StandardWindow("test", "python-elementary test application",
         size=(320,520))
     win.callback_delete_request_add(lambda o: elementary.exit())
@@ -760,6 +824,7 @@ if __name__ == "__main__":
         ("Genlist Decorate Item Mode", genlist10_clicked),
         ("Genlist Decorate All Mode", genlist15_clicked),
         ("Genlist Search By Text", genlist20_clicked),
+        ("Genlist Reorder Mode", genlist11_clicked),
     ]
 
     li = List(win, size_hint_weight=EXPAND_BOTH, size_hint_align=FILL_BOTH)
@@ -773,4 +838,3 @@ if __name__ == "__main__":
 
     win.show()
     elementary.run()
-    elementary.shutdown()
